#
# spec file for package spectacle
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.10.0
%define qt6_version 6.7.0
%define rname spectacle
# Full Plasma 6 version (e.g. 6.0.0)
%{!?_plasma6_bugfix: %global _plasma6_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 6.0 in KF6, but 6.0.80 in KUF)
%{!?_plasma6_version: %define _plasma6_version %(echo %{_plasma6_bugfix} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           spectacle
Version:        6.3.2
Release:        1.1
Summary:        Screen Capture Program
License:        GPL-2.0-or-later AND LGPL-2.0-or-later
URL:            https://apps.kde.org/spectacle
# Tarball had to be redone, but is still version 6.3.2 inside
Source0:        https://download.kde.org/stable/plasma/6.3.2/spectacle-6.3.2.1.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/6.3.2/spectacle-6.3.2.1.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  qt6-gui-private-devel >= %{qt6_version}
BuildRequires:  systemd-rpm-macros
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6GlobalAccel) >= %{kf6_version}
BuildRequires:  cmake(KF6GuiAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiPlatform) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6Prison) >= %{kf6_version}
BuildRequires:  cmake(KF6Purpose) >= %{kf6_version}
BuildRequires:  cmake(KF6StatusNotifierItem) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(OpenCV)
# _plasma6_version requires awk which OBS can't do, but MACRO results in have choice.
BuildRequires:  cmake(KPipeWire) >= %{_plasma6_bugfix}
BuildRequires:  cmake(LayerShellQt) >= %{_plasma6_bugfix}
BuildRequires:  cmake(PlasmaWaylandProtocols)
BuildRequires:  cmake(Qt6Concurrent) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Multimedia) >= %{qt6_version}
BuildRequires:  cmake(Qt6PrintSupport) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickTemplates2) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6WaylandClient) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  cmake(ZXing) >= 1.2.0
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(xcb-cursor)
BuildRequires:  pkgconfig(xcb-image)
BuildRequires:  pkgconfig(xcb-randr)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xcb-xfixes)
Requires:       qt6-imageformats >= %{qt6_version}

%description
Spectactle is a screenshot-taking program made by KDE. It allows taking screenshots
of screens, windows, regions of the screen, and to export them to files or other
online services.

%package doc
Summary:        Documentation for Spectacle
Requires:       spectacle

%description doc
This package contains the documentation available for Spectacle, which is a
screenshot capture program by KDE.

%lang_package
%lang_package -n spectacle-doc

%prep
%autosetup -p1 -n spectacle-6.3.2

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --with-man --all-name
%find_lang %{name}-doc --with-html --without-mo --all-name

%post
%{systemd_user_post app-org.kde.spectacle.service}

%preun
%{systemd_user_preun app-org.kde.spectacle.service}

%postun
%{systemd_user_postun app-org.kde.spectacle.service}

%files
%license LICENSES/*
%doc %lang(en) %{_mandir}/man1/spectacle.1.gz
%{_kf6_applicationsdir}/org.kde.spectacle.desktop
%{_kf6_appstreamdir}/org.kde.spectacle.appdata.xml
%{_kf6_bindir}/spectacle
%{_kf6_dbusinterfacesdir}/org.kde.Spectacle.xml
%{_kf6_debugdir}/spectacle.categories
%{_kf6_iconsdir}/hicolor/scalable/apps/spectacle.svg
%{_kf6_libdir}/kconf_update_bin/spectacle-24.02.0-change_placeholder_format
%{_kf6_libdir}/kconf_update_bin/spectacle-24.02.0-keep_old_filename_templates
%{_kf6_libdir}/kconf_update_bin/spectacle-24.02.0-keep_old_save_location
%{_kf6_libdir}/kconf_update_bin/spectacle-24.02.0-rename_settings
%{_kf6_libdir}/kconf_update_bin/spectacle-24.02.0-video_format
%{_kf6_notificationsdir}/spectacle.notifyrc
%{_kf6_sharedir}/dbus-1/services/org.kde.Spectacle.service
%{_kf6_sharedir}/dbus-1/services/org.kde.spectacle.service
%dir %{_kf6_sharedir}/kglobalaccel
%{_kf6_sharedir}/kglobalaccel/org.kde.spectacle.desktop
%{_kf6_sharedir}/kconf_update/spectacle.upd
%{_userunitdir}/app-org.kde.spectacle.service

%files doc
%doc README.md
%doc %lang(en) %{_kf6_htmldir}/en/spectacle/

%files lang -f %{name}.lang

%files doc-lang -f %{name}-doc.lang
%exclude %{_kf6_htmldir}/en/spectacle/

%changelog
* Tue Feb 25 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.2
- Changes since 6.3.1.2:
  * update version for new release
  * Remove 24.12 versions from appstream file (kde#500396)
  * Revert "reroll"
* Wed Feb 19 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.1.2:
  * New bugfix release
  * Tarball built from the correct branch now
* Tue Feb 18 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.1
- No code changes since 6.3.0
* Sat Feb 15 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.0:
  * New bugfix release
  * Now part of Plasma
  * For more details see https://kde.org/announcements/plasma/6/6.3.0
- No code changes since 24.12.2
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- Changes since 24.12.1:
  * OptionsMenu: remove extra separator
  * OptionsMenu: only check capture on click when it's possible to use it
  * OptionsMenu: Don't put separator before capture on click checkbox when the checkbox isn't visible
  * OptionsMenu: Check the rectangle mode action in rectangle mode
  * Force QR code inline message to always be HTML (kde#498618)
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- No code change since 24.12.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- Changes since 24.11.80:
  * Fix webp capitalization
  * Add warning notification when WebP support is missing
  * Revert "Require webp for recording system tray icon"
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Changes since 24.08.3:
  * Don't include quiet packages in feature_summary
  * Require webp for recording system tray icon
  * Use kstandardactions
  * Fix negative animation duration without capture on click support (kde#495216)
  * cmake: remove excess include dir
  * work around bugged qmlcachegen (kde#494281)
  * AnnotationViewport: fix stretching odd sized images
  * ImagePlatformKWin: Use a 60 second timeout for CaptureInteractive
  * ExportManager: fix crash when saving while timezone is misconfigured (kde#493191)
  * ExportManager: rename removeEmptyPlaceholderAndSeparators to removePlaceholderAndSeparators
  * ExportManager: Fix Save As using default filename template and wrong folder for filename formatting (kde#493370)
  * ExportManager: Make Placeholder a bit more efficient
  * Use blur and pixelate icons for blur and pixelate tools
  * Generate wayland code with PRIVATE_CODE
  * Round mouse positions to physical pixels (kde#489448)
  * Set fallback icon theme (kde#492824)
  * Reuse tooltip for annotation tool buttons
  * Make it easier to click annotation tool buttons
  * Don't disable AnnotationEditor with NoTool selected
  * Move undo/redo shortcuts to AnnotationEditor
  * Fix InlineMessage headers/appearance on "no screenshot" dialog
  * Set suggested filename for copied images
  * Go back to copying images with setImageData (kde#485096)
  * Set maximum pending frame buffer size based on available memory
  * VideoPlatformWayland: remove inaccurate comment
  * Fix deprecated version
  * Set up crash handling
  * Sanitise html in barcodes
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- Changes since 24.08.2:
  * work around bugged qmlcachegen (kde#494281)
  * Fix negative animation duration without capture on click support (kde#495216)
  * AnnotationViewport: fix stretching odd sized images
  * Revert "Make screenshots with scales multiplied or divided by integers look sharper in AnnotationViewport"
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- Changes since 24.08.1:
  * ImagePlatformKWin: Use a 60 second timeout for CaptureInteractive
  * ExportManager: fix crash when saving while timezone is misconfigured (kde#493191)
  * ExportManager: Make Placeholder a bit more efficient
  * ExportManager: rename removeEmptyPlaceholderAndSeparators to removePlaceholderAndSeparators
  * ExportManager: Fix Save As using default filename template and wrong folder for filename formatting (kde#493370)
  * Make screenshots with scales multiplied or divided by integers look sharper in AnnotationViewport
  * Use blur and pixelate icons for blur and pixelate tools
  * Round mouse positions to physical pixels (kde#489448)
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- Changes since 24.08.0:
  * Set fallback icon theme (kde#492824)
  * Fix InlineMessage headers/appearance on "no screenshot" dialog
  * Set suggested filename for copied images
  * Go back to copying images with setImageData (kde#485096)
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Too many changes since 24.05.2, only listing bugfixes:
  * Rename 24.02.0-change_placeholder_format script ID to 24.05.2-change_placeholder_format (kde#484211)
  * AnnotationDocument: Fix highlighter tool not blending with base image (kde#488025)
  * Prevent TextTool TextEdit shortcuts from being used by the window while TextTool is focused (kde#487740)
  * ExportManager: keep dir separators near <title> (kde#445084)
  * Always convert old placeholder format to new placeholder format when new format is not used (kde#484211)
  * Fix empty <title> placeholders breaking nearby placeholders (kde#483320)
  * Raise and activate capture windows when shown (kde#482467)
  * Improve feedback when recording is not available (kde#484038)
  * ImagePlatformKWin: Use logical positions for images in combinedImage on X11 (kde#486118)
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- Changes since 24.05.1:
  * History: fix strict-aliasing warnings by using std::ranges
  * Rename 24.02.0-change_placeholder_format script ID to 24.05.2-change_placeholder_format (kde#484211)
  * Prevent TextTool TextEdit shortcuts from being used by the window while TextTool is focused (kde#487740)
  * AnnotationDocument: Preserve image metadata
  * ExportManager: Even more handling for empty <title>
  * ExportManager: remove duplicate dir separators
  * ExportManager: keep dir separators near <title> (kde#445084)
  * FilenameTest: use a map and for loops for testing titles instead of copy/pasting strings
  * Use new placeholder format for the keep_old_filename_templates script
  * Lock temp dirs while still in use
  * ConfigUtils: rename continueUpdate to isFileOlderThanDateTime
  * Fixed warning
  * Removed unused members
  * Traits: make getImage a const reference
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- Changes since 24.05.0:
  * AnnotationDocument: Fix highlighter tool not blending with base image (kde#488025)
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- Changes since 24.04.80:
  * Always convert old placeholder format to new placeholder format when new format is not used (kde#484211)
  * Fix empty <title> placeholders breaking nearby placeholders (kde#483320)
  * ExportManager: reduce unnecessary string manipulation in formattedFilename()
  * VideoCaptureOverlay: Minimized -> Window.Minimized
  * Raise and activate capture windows when shown (kde#482467)
  * Use HH instead of hh by default
  * SpectacleCore: Only use normal windows and dialogs for window visible check
  * ImagePlatformXcb: Make on click filter button handling code more descriptive
  * VideoPlatformWayland: handle and add error messages for when the stream is prematurely closed
  * VideoPlatform: don't assert recording boolean in setRecording
  * VideoPlatformWayland: Remove the need for a DBus call to KWin's getWindowInfo
  * Update recording related models in response to VideoPlatform changes
  * VideoPlatformWayland: Get PipeWireRecord asynchronously
  * VideoPlatformWayland: Add missing not operator
  * Improve feedback when recording is not available (kde#484038)
  * SpectacleCore: use shared error behavior for screenshot and recording failures
  * RecordingFailedMessage: fix close button
  * SpectacleCore: move video platform setup code closer to image platform setup code
  * SpectacleCore: use VideoPlatform::regionRequested to start rectangle selection
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Too many changes since 24.02.2, only listing bugfixes:
  * ImagePlatformKWin: Use logical positions for images in combinedImage on X11 (kde#486118)
  * Add blur/pixelate strength settings and slider for adjusting them (kde#469184)
  * Fix sequence numbers in filenames (kde#483260)
  * Disable video mode when a new rectangle capture screenshot is started (kde#481471)
  * Handle: prevent division by zero in ShapePath scale (kde#484892)
  * ImagePlatformKWin: Go back to manually combining images (kde#478426)
  * Add crop tool (kde#467590)
  * Add backend logic for undoable cropping (kde#481435)
  * SpectacleCore: make class inheritance check more robust (kde#484652)
  * Add recording options to the no screenshot dialog (kde#468778)
  * AnnotationViewport: Don't use TextureCanUseAtlas (kde#481665)
  * Finish recording instead of activating when activated from shortcut while recording (kde#481471)
  * Set layer-shell exclusive zone for capture region overlay (kde#481391)
  * Use KConfigDialogManager system instead of directly setting video format (kde#481390)
  * ViewerWindow: Check if s_viewerWindowInstance points to this when destroying (kde#469502)
  * Fix always recording the screen at (0,0) with screen recording (kde#480599)
  * Add support for new lines and tabstops in text annotations (kde#472302)
  * Remove X11 atom (kde#478162)
  * Add <UnixTime> filename placeholder (kde#478802)
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- Changes since 24.02.1:
  * SpectacleCore: make class inheritance check more robust (kde#484652)
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Finish recording instead of activating when activated from shortcut while recording (kde#481471)
  * Ensure region recording outline stays out of recording
  * Set layer-shell exclusive zone for capture region overlay (kde#481391)
  * Fix selection tool
  * Use KConfigDialogManager system instead of directly setting video format (kde#481390)
  * Fix filename template label buddies
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- Changes since 24.01.95:
  * Fix filename template label buddies
  * Fix drawing with touchscreen
  * ViewerWindow: Check if s_viewerWindowInstance points to this when destroying (kde#469502)
  * Fix always recording the screen at (0,0) with screen recording (kde#480599)
  * Do not loop video player and pause on playback stopped
  * recording: Play the video after it has recorded
  * Fix invalid timestamp when opening config dialog before screen capture
  * recording: Do not leak node ids
  * Fix unclickable buttons on dialog window after startSystemMove() is called
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Wed Feb  7 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Drop meanwhile unneeeded BuildReqs on kColorPicker and
  kImageAnnotator
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * snapcraft: initial import snapcraft files.
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * Fix crash in QApplication::screenRemoved lambda
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes since 23.04.3, only listing bugfixes:
  * Avoid auto quitting on auto save (kde#469646)
  * Use ecm_query_qt to query Qt binaries dir (kde#471095)
  * Multiply annotation shadow opacity by stroke or fill opacity (kde#464170)
  * Allow making annotation colors fully transparent via checkboxes (kde#468077)
  * Hide redundant header on Wayland (kde#468818)
  * Fix wrong image position in rectangle capture mode with scaling (kde#462860)
  * Fix quitting Spectacle with Escape affecting windows below it (kde#428478)
  * Don't close all windows if activated by DBus with GUI and no CLI options (kde#467118)
  * Fix window title file name template on wayland (kde#465524)
  * Use deleteLater() to delete SpectacleWindows (kde#467401)
  * AnnotationDocument: Divide image size by devicePixelRatio in addImage() (kde#467398)
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Fix the capture option panel width for some languages
* Mon May 22 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix systemd_user_post/preun/postun calls: all systemd_user macros
  take service names as parameter.
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * Increase default stroke size for rectanlge and ellipse annotations
  * Undo making it possible to uncheck font
  * Multiply annotation shadow opacity by stroke or fill opacity (kde#464170)
  * Use transparent default fill color for rectangle and ellipse annotations
  * Allow making annotation colors fully transparent via checkboxes (kde#468077)
  * return early if action is null in Utils::shapeShadow()
  * Hide redundant header on Wayland (kde#468818)
  * Add pragma once to ScreenShotEffect.h
  * Add pragma once to PlasmaVersion.h
  * PlasmaVersion: clean up header file
  * Warn when screenshot effect isn't available on wayland, exit if no GUI
  * Fix segfaults from xcb function calls not getting replies fast enough
  * Fix warning about plasmashell service without plasmashell
  * Enable autoRepeat for Undo/Redo buttons
  * Only add 200ms delay if Plasma version is less than 5.27.4
  * Fix quitting Spectacle with Escape affecting windows below it (kde#428478)
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * clean forward declaration
  * Darken/lighten the rectangular region overlay
  * Adapt build system for building against qt6
  * Const'ify variable. Initialize it. Use forward declaration
  * const'ify pointer
  * Fix mem leak (actions created in init() method)
  * const'ify method/variables
  * Minor: Respect KDE HIG
  * Add timezone placeholder "%%t"
  * Respect -c, in combination with -b, to only save image into clipboard (kde#447811)
  * Simplify branching for the notify text and fix messages containing dots (kde#447517)
  * It's enabled by default in qt6
  * Make DocTools as optional
  * Inconsistency between man page and actual available command line options (kde#446710)
  * Reenable the user set dbus values ignored by MR98
  * Wayland: Allow to copy to clipboard img while in dbus or background mode (kde#429390)
  * Replace last emit with Q_EMIT
  * Fix build without KImageAnnotator
  * Add "snipping tool" to keywords list
  * Save Annotation tool settings across launches
  * Check for min version of kImageAnnotator
  * Enable newly introduced controls within kImageAnnotator
  * Drop KIPI support
  * Respect in-windows settings when launched via DBUS (kde#392057)
  * Add feature to annotate existing screenshots (kde#431257)
  * Add CI
  * Use KIO::JobUiDelegate for opening other application (kde#445530)
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- Changes since 21.12.1:
  * Show magnifier immediately after toggle
  * Make tools button visible even if no screenshot has been taken
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * Check for right/middle click in Platform*.cpp
  * Do not show error message when canceling with rightclick while in rectangluar mode (kde#446882)
  * Cancel drag and drop if there is no screenshot in the preview.
  * Disable buttons that shouldn't be available when no screenshot was taken (kde#446578)
  * Disable Annotate button when there's no image
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Changes since 21.11.80:
  * Use KIO::JobUiDelegate for opening other application (kde#445530)
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Too many changes since 21.08.3, only listing bugfixes:
  * Annotation: set canvas background to transparent (kde#432753)
  * Do not duplicate text when using -c (kde#433221)
  * Add support for Active Window mode on Wayland (kde#386271)
  * Keep screenshot preview within a reasonable size when drag and drop is initiated (kde#443564)
  * Fix capturing from depth 30 screens (10bpc) (kde#422285)
  * Prevent session manager from restoring the app on start up (kde#430411)
  * Copy the correct file path to clipboard (kde#441047)
  * ExportManager: delay copy to clipboard (kde#421974)
  * Wayland: when screens have same dpr use NativeSize (kde#440226)
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- No code change since 21.08.1
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- Changes since 21.08.0:
  * ExportManager: delay copy to clipboard (kde#421974)
  * Wayland: when screens have same dpr use NativeSize (kde#440226)
  * Don't show an error message when user cancels screenshot in progress on Wayland
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- No code change since 21.07.80
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Changes since 21.04.3:
  * Update IRC network name in the manpage
  * Load translations for kImageAnnotator
  * Add global shortcut to open Spectacle in 'Window Under Cursor' mode (kde#435083)
  * Fix some clazy warning
  * X11: Use correct width and height for region selection window
    and its contents when scaling is enabled (kde#400921)
  * Sync docs with the current interface
  * Adjust settings window's proportions a bit
  * Take font size into consideration for settings window size
  * Set default window sizes properly using sizeHint()
  * fix: improve the explanatory text for doNothing Radio button,
    after-screenshot clipboard action
  * feat: add support to copy image and copy file path from the command
    line in background mode
  * feat: add support to copy the location to clipboard after screenshot
    even when auto save is not enabled
  * feat: add new kcfg settings for after screenshot clipboard preferences
  * feat: use radio buttons for after screenshot clipboard actions
  * Fix typo
  * Correct homepage URLs
  * Fix SVG image
  * Add clipboard icon to copy to clipboard toolbutton
  * Sync docs with the current interface
  * Add missing Qt5Concurrent
  * feat: add support for copying saved screenshot file path to clipboard
  * Add support for screen geometry with negative coordinates
  * feat: group 'copy to *' options together and move 'autosave' option to the top
  * Simplify QuickEditor
  * Update manual
  * Cleanup QuickEditor code
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- Changes since 21.04.2:
  * Fix crash in all(?) KIPI export plugins
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- Changes since 21.04.1:
  * Platforms: Introduce PlatformKWinWayland2 (kde#437652)
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- No code change since 21.04.0
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
- Stop owning directories provided by the filesystem package (boo#1184786)
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes since 20.12.3, only listing bugfixes:
  * fix lookup of ComparableQPoint keys in QMap (kde#430942)
  * Don't translate property name (kde#431557)
  * PlatformKWinWayland: avoid recursion in readData (kde#428636)
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- Changes since 20.12.2:
  * Fix compression quality range
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- Changes since 20.12.1:
  * If region capture is cancelled, close Spectacle (kde#432006)
  * fix lookup of ComparableQPoint keys in QMap (kde#430942)
  * Don't translate property name (kde#431557)
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- Changes since 20.12.0:
  * Changed signal of Annotate button in main window from pressed to clicked in order to let annotation mode appear after button is released.
  * We do not need progress info when checking if a file exists (kde#430173)
  * Remove dead code variant
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- Changes since 20.11.90:
  * PlatformKWinWayland: avoid recursion in readData (kde#428636)
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- Changes since 20.11.80:
  * Support Wayland rectangular selection HiDpi (kde#409762)
  * fix autoincrement of %%d for templates with subdirs
  * Set pixmap device pixel ratio before sending it to kimageannotator
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Too many changes since 20.08.3, only listing bugfixes:
  * Unhide window if it is hidden (kde#428635)
  * Separate messages for a failed and canceled screenshot (kde#427645)
  * Use default value for including decorations and pointer in background mode (kde#425995)
  * Improve settings logic and layout (kde#420477)
  * Respect settings and cli parameters (kde#425573)
  * Add CLI options for including pointer/decorations (kde#425995)
  * Fix wrong file name when --output option is used (kde#424380)
- Drop upstream patch:
  * 0001-Fix-wrong-file-name-when-output-option-is-used.patch
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- Changes since 20.08.2:
  * ExportManager: Marked saved files as recent files (kde#424205)
  * QuickEditor: Use XCB API to position the editor window
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- Changes since 20.08.1:
  * Properly position QuickEditor when HiDPI support is on (kde#385885)
* Thu Sep 17 2020 Luca Beltrame <lbeltrame@kde.org>
- Add upstream patch to fix --output command line option
  (kde#424380):
  * 0001-Fix-wrong-file-name-when-output-option-is-used.patch
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- No code change since 20.08.0
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- No code change since 20.07.90
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- Changes since 20.07.80:
  * Hide mouse pointer by default (kde#397121)
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- Too many changes since 20.04.3, only listing bugfixes:
  * Wayland: allow to take immediate and delayed screenshots (kde#414532)
  * Refactor Spectacle to run in single instance mode with KDBusService::Unique (kde#420477)
  * Use the common name for the 'PrtSc' key in docs (kde#419247)
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- No code change since 20.04.2
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * Disconnect after receiving screenshot signal (kde#412186)
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- Changes since 20.03.90:
  * Fix inability to Drag+Drop screenshot due to subfolder in filename (kde#417722)
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- Changes since 20.03.80:
  * Qt guys reverted api in qt5.15
  * Make region options exclusive again (kde#419072)
  * Add missing includes
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes since 19.12.3, only listing bugfixes:
  * Escape filename before operating on it with regular expressions (kde#418638)
  * Find qdbus command correctly (kde#413007)
  * Take screenshot with currently selected options (kde#415688)
  * Pass only the path to the file dialog (kde#416629)
  * Port towards KConfig XT (kde#389894)
- Dropped patches, superseded by upstream changes:
  * 0001-Use-qdbus-qt5-instead-of-qdbus.patch
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- No code change since 19.12.2
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- Changes since 19.12.1:
  * tests: make sure testNumbering works
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Changes since 19.12.0:
  * Update Appstream for new release
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Update Appstream for new release
  * Fix issue preventing spectacle from opening
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- No code change since 19.11.80
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Too many changes since 19.08.3, only listing bugfixes:
  * Add new touch-friendly drag handlers (kde#371843)
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- Changes since 19.08.2:
  * Make all buttons in the main window activatable with enter (kde#412184)
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- Changes since 19.08.1:
  * CMD arguments and CaptureMode was mixed up
  * FIX: Properly close spectacle after Save As
  * Make QuickEditor fullscreen on Wayland
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- Changes since 19.08.0:
  * FIX: Close spectacle if it's started with: -b -c
  * Fix Quickeditor only be shown on one screen on  Wayland
  * Don't exit when running in gui mode and notification times out
  * Allow Spectacle to build with KConfig <= 5.56.0
- Refreshed patches:
  * 0001-Use-qdbus-qt5-instead-of-qdbus.patch
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- No code change since 19.07.90
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- Changes since 19.07.80:
  * Use correct KPageDialog face style for settings window
  * Use QTEST_GUILESS_MAIN
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Too many changes to list here
- Refreshed patches:
  * 0001-Use-qdbus-qt5-instead-of-qdbus.patch
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- No code changes since 19.04.2
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- Changes since 19.04.1:
  * Don't exit when running in gui mode and notification times out
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- Changes since 19.04.0:
  * Respect the user-configured mimetype when dragging an image from the main window (kde#407165)
  * Set compression to 50 if the format is png (kde#406263)
  * Add DesktopEntry to notifyrc
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- Changes since 19.03.90:
  * Change default compression quality from 90 to 89
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * Add missing QMimeData include to fix compilation on older Qt versions
  * Make "Quit after copy" feature work (kde#393708)
  * Change i18n of filename formatting options
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Too many changes to list here
- Add 0001-Use-qdbus-qt5-instead-of-qdbus.patch to ensure the right
  qdbus command is used by spectacle
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * Use more https in links
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * No code changes since 18.11.80
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Too many changes to list here
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * No code changes since 18.08.2
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * None
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Fix missing notification title found by -Wswitch-enum
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * Rework rectangle/arrow key handling to avoid "stuck edges" and 0x0px rectangle
  * Add license header to TextLabel.qml
  * Fix rendering of on-screen help texts for fractional scaling
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Too many changes to list here
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * None
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * None
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * Fix memory leaks
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * None
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Too many changes to list here
- Dropped patches, now upstream:
  * 0001-Decide-to-use-the-wayland-backend-by-looking-at-XDG_.patch
- Update description: it's "by KDE", not "for KDE"
* Sat Mar 24 2018 fabian@ritter-vogt.de
- Add patch to fix taking screenshots on wayland without the wayland
  platform plugin:
  * 0001-Decide-to-use-the-wayland-backend-by-looking-at-XDG_.patch
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * None
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * None
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * None
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * None
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * None
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * bump date and releaseinfo
  * fix spectacle documentation
  * Clean up and standardize Settings dialog
  * Make dark overlay less dark, and light overlay less washed out (kde#368739)
  * Drop some app metadata setting which KAboutData::setApplicationData does
  * Allow to create bugzilla version
  * Fix message when the image was shared using a plugin that doesn't reply with a URL
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * Fix crash in X11ImageGrabber::getDrawableGeometry.
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * Fix .arcconfig
  * Hint to drop handlers we only want to offer copy of data, not move
  * Add .arcconfig
  * Fix: use autosaveFilename format also for files exported via DnD or menu (kde#382718)
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * None
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
  * Use Q_DECL_OVERRIDE
  * Update Spectacle docbook
  * Allow shrinking of dialog (kde#376387)
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sun Jul 16 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * None
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * None
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * None
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * None
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * Allow shrinking of dialog
  * Selection text shows floating point rounding errors
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Disable mismatched tags errors with clang
  * change codename for 17.04
  * Allow use of alternative user-configured image format when auto-saving.
  * Add Appstream summary
  * Set screenshot URL for notification
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * None
* Fri Feb 10 2017 lbeltrame@kde.org
- Drop set-screenshot-URL-for-notification.patch, merged upstream
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 21 2017 fabian@ritter-vogt.de
- Add patch to support Plasma 5.9 feature of images in notifications:
  * set-screenshot-URL-for-notification.patch
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Fri Jul  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Tue Dec 15 2015 tittiatcoke@gmail.com
- Initial version based on KDE Applications 15.12.0
  * Replacement for ksnapshot
